@@ -33,7 +33,7 @@
 
 /**
  * GtkSourceStyleScheme:
- * 
+ *
  * Controls the appearance of [class@View].
  *
  * #GtkSourceStyleScheme contains all the text styles to be used in
@@ -641,8 +641,8 @@ get_color (GtkSourceStyle *style,
  * Returns TRUE if the style for current-line is set in the scheme
  */
 gboolean
-_gtk_source_style_scheme_get_current_line_color (GtkSourceStyleScheme *scheme,
-                                                 GdkRGBA              *color)
+_gtk_source_style_scheme_get_current_line_background_color (GtkSourceStyleScheme *scheme,
+							    GdkRGBA              *color)
 {
 	GtkSourceStyle *style;
 
@@ -665,6 +665,40 @@ _gtk_source_style_scheme_get_current_line_number_color (GtkSourceStyleScheme *sc
 
 	style = gtk_source_style_scheme_get_style (scheme, STYLE_CURRENT_LINE_NUMBER);
 
+	return get_color (style, TRUE, color);
+}
+
+gboolean
+_gtk_source_style_scheme_get_current_line_number_bold (GtkSourceStyleScheme *scheme)
+{
+	GtkSourceStyle *style;
+	gboolean bold_set = FALSE;
+	gboolean bold = FALSE;
+
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme), FALSE);
+
+	if ((style = gtk_source_style_scheme_get_style (scheme, STYLE_CURRENT_LINE_NUMBER)))
+	{
+		g_object_get (style,
+		              "bold-set", &bold_set,
+		              "bold", &bold,
+		              NULL);
+	}
+
+	return !bold_set || bold;
+}
+
+gboolean
+_gtk_source_style_scheme_get_current_line_number_background_color (GtkSourceStyleScheme *scheme,
+                                                                   GdkRGBA              *color)
+{
+	GtkSourceStyle *style;
+
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme), FALSE);
+	g_return_val_if_fail (color != NULL, FALSE);
+
+	style = gtk_source_style_scheme_get_style (scheme, STYLE_CURRENT_LINE_NUMBER);
+
 	return get_color (style, FALSE, color);
 }
 
@@ -860,6 +894,43 @@ get_css_color_style (GtkSourceStyle *style,
 	}
 }
 
+static void
+fix_broken_selection (char **bg_out,
+		      char **text_out)
+{
+	char *bg = *bg_out;
+	char *text = *text_out;
+	char *tmp = NULL;
+	const char *space;
+	const char *semi;
+	GdkRGBA rgba;
+
+	/* If there is no foreground and the background is solid, we must
+	 * alter it to be transparent or some systems will not see anything
+	 * (such as those in libadwaita).
+	 */
+
+	if ((space = strchr (bg, ' ')) &&
+	    (semi = strchr (space, ';')) &&
+	    (tmp = g_strndup (space + 1, semi - space - 1)) &&
+	    gdk_rgba_parse (&rgba, tmp) &&
+	    rgba.alpha >= 1.0)
+	{
+		char *new_bg;
+		rgba.alpha = .3;
+		new_bg = gdk_rgba_to_string (&rgba);
+		g_free (bg);
+		text = g_strdup ("color: rgba(0,0,0,0);");
+		bg = g_strdup_printf ("background-color: %s;", new_bg);
+		g_free (new_bg);
+	}
+
+	g_free (tmp);
+
+	*bg_out = bg;
+	*text_out = text;
+}
+
 static void
 append_css_style (GString        *string,
                   GtkSourceStyle *style,
@@ -873,8 +944,12 @@ append_css_style (GString        *string,
 		"}\n";
 
 	get_css_color_style (style, &bg, &text);
+
 	if (bg || text)
 	{
+		if (bg && !text && g_str_has_suffix (selector, " selection"))
+			fix_broken_selection (&bg, &text);
+
 		g_string_append_printf (string, css_style, selector,
 		                        bg != NULL ? bg : "",
 		                        text != NULL ? text : "");
